summaryrefslogtreecommitdiff
path: root/libevdev
diff options
context:
space:
mode:
authorPeter Hutterer <peter.hutterer@who-t.net>2019-01-16 13:17:33 +1000
committerPeter Hutterer <peter.hutterer@who-t.net>2019-01-16 13:17:33 +1000
commit6852dadbca2720621ce4699a03d35f791e9d7ebe (patch)
tree057dbadd3d7d50a9c08b6d0350c2da2a40064423 /libevdev
parent29628dc2c3bc64237af6a092aae99a4100b8df5b (diff)
downloadlibevdev-6852dadbca2720621ce4699a03d35f791e9d7ebe.tar.gz
Replace ABS_MT_SLOT - 1 with the v4.20 ABS_RESERVED define
ABS_RESERVED was added to 4.20 for that reason, to keep that event code reserved so we can't use it for anything else (and thus mess up the fake MT detection). Signed-off-by: Peter Hutterer <peter.hutterer@who-t.net>
Diffstat (limited to 'libevdev')
-rw-r--r--libevdev/libevdev.c4
-rw-r--r--libevdev/libevdev.h2
2 files changed, 3 insertions, 3 deletions
diff --git a/libevdev/libevdev.h b/libevdev/libevdev.h
index f0f34bb..198b684 100644
--- a/libevdev/libevdev.h
+++ b/libevdev/libevdev.h
@@ -688,7 +688,7 @@ extern "C" {
* meaning, matching the axis names in linux/input.h. Some devices merely
* export a number of axes beyond the available axis list. For those
* devices, the multitouch information is invalid. Specifically, if a device
- * provides the ABS_MT_SLOT axis AND also the (ABS_MT_SLOT - 1) axis, the
+ * provides the ABS_MT_SLOT axis AND also the ABS_RESERVED axis, the
* device is not treated as multitouch device. No slot information is
* available and the ABS_MT axis range for these devices is treated as all
* other EV_ABS axes.
diff --git a/libevdev/libevdev.c b/libevdev/libevdev.c
index fab87cf..761ba5a 100644
--- a/libevdev/libevdev.c
+++ b/libevdev/libevdev.c
@@ -461,10 +461,10 @@ libevdev_set_fd(struct libevdev* dev, int fd)
dev->fd = fd;
/* devices with ABS_MT_SLOT - 1 aren't MT devices,
see the documentation for multitouch-related
functions for more details */
- if (!libevdev_has_event_code(dev, EV_ABS, ABS_MT_SLOT - 1) &&
+ if (!libevdev_has_event_code(dev, EV_ABS, ABS_RESERVED) &&
libevdev_has_event_code(dev, EV_ABS, ABS_MT_SLOT)) {
const struct input_absinfo *abs_info;
@@ -461,10 +461,10 @@ libevdev_set_fd(struct libevdev* dev, int fd)
dev->fd = fd;
- /* devices with ABS_MT_SLOT - 1 aren't MT devices,
+ /* devices with ABS_RESERVED aren't MT devices,
see the documentation for multitouch-related
functions for more details */